Learn R Programming

RapidPolygonLookup (version 0.1.1)

sf.crime.2012: Sample data with lat/long information

Description

2012 crime incident data from the city of San Francisco

Usage

data(sf.crime.2012)

Arguments

Format

A data frame with 20,000 randomly selected observations with the following variables and their types:

Date

character

X

numeric

Y

numeric

violent

Factor

Details

There are no more details required

Examples

Run this code
# NOT RUN {
data(sf.crime.2012, envir = environment())
# }

Run the code above in your browser using DataLab