powered by
2012 crime incident data from the city of San Francisco
data(sf.crime.2012)
A data frame with 20,000 randomly selected observations with the following variables and their types:
Date
character
X
numeric
Y
violent
Factor
There are no more details required
# NOT RUN { data(sf.crime.2012, envir = environment()) # }
Run the code above in your browser using DataLab